==> lian5-ji7-hu5_kiam2-tsa1-0.3.1.tar.gz: lian5-ji7-hu5_kiam2-tsa1-0.3.1/連字符檢查/動詞原則/動詞.py <==
from 臺灣言語工具.音標系統.閩南語.臺灣閩南語羅馬字拼音 import 臺灣閩南語羅馬字拼音
from 臺灣言語工具.基本物件.詞 import 詞


def 是環綴起始(字分詞):
    集合 = ('會｜e7', '袂｜be7', '袂｜bue7')
    return 字分詞 in 集合


def 是環綴結尾(字分詞):
    集合 = ('得｜tit4', '得｜tsit4', '得｜lit4', '得｜eh4')
    return 字分詞 in 集合


def 是動詞(詞分詞):
    集合 = ('徛｜khia7', '看｜khuann3', '講｜kong2', '排｜pai5', '整-理｜tsing2-li2')
    return 詞分詞 in 集合


def 是助詞(字分詞):
    集合 = ('咧｜leh4', '咧｜teh4', '著｜tioh8', '過｜kue3')
    return 字分詞 in 集合


def 是咧結尾詞組(詞分詞):
    集合 = ('佇-咧｜ti7-leh4', '當-咧｜tng1-leh4', '當-咧｜tng1-teh4')
    return 詞分詞 in 集合


def 是咧開頭詞組(詞分詞):
    集合 = ('咧-欲｜teh4-beh4', )
    return 詞分詞 in 集合


def 是著結尾詞組(詞分詞):
    集合 = ('毋-著｜m̄-tio̍h',)
    return 詞分詞 in 集合


def 是補語(詞分詞):
    # 照字數排
    集合 = ('做-伙｜tso3-hue2', '好-勢｜ho2-se3', '煞｜suah4', '了｜liau2', '好｜ho2', )
    return 詞分詞 in 集合


def 是否符合環綴原則(句物件):
    # 動詞原則一：動詞與環綴連寫
    # 會...得，袂...得
    錯誤訊息陣列 = []
    累積字長度 = 0
    #
    # 我會記得你 -> 我, 會記得, 你
    詞物件陣列 = 句物件.網出詞物件()
    #
    # 會-記-得  1-1-1
    # 會-記 得  1-1 2 後面沒連寫
    # 會 記-得  1 2-2 錯誤
    # 會 記 得  1 2 3 錯誤
    #
    環綴起始詞 = None
    for 詞位置, 詞物件 in enumerate(詞物件陣列):
        詞的字物件陣列 = 詞物件.篩出字物件()
        詞長度 = len(詞的字物件陣列)

        for 字物件 in 詞的字物件陣列:
            字分詞 = 字物件.轉音(臺灣閩南語羅馬字拼音).看分詞()
            # 遇到可能是環綴起始的詞，先暫存此位置
            if 是環綴起始(字分詞):
                環綴起始詞 = {'詞位置': 詞位置, '字陣列': 詞的字物件陣列, '累積字長度': 累積字長度}
            # 遇到可能是環綴結尾的詞
            # if 是環綴結尾 and 前面有找到環綴起始詞 and 環綴起始詞的詞位置 != 現在環綴結尾詞的詞位置
            elif 是環綴結尾(字分詞) and 環綴起始詞:
                if 環綴起始詞['詞位置'] != 詞位置:
                    # 偵測到句子有出現環綴，檢查環綴的書寫是否正確
                    環綴結尾詞 = 詞的字物件陣列
                    # 首字應連寫
                    # 會 記-得  1 2-2 錯誤
                    # 會 記 得  1 2 3 錯誤
                    if len(環綴起始詞['字陣列']) == 1:
                        錯誤行數 = 環綴起始詞['累積字長度'] + 1
                        錯誤連字符位置 = '後'
                        錯誤訊息陣列.append(('E動詞（一）', 錯誤行數, 錯誤連字符位置))
                    # 尾字應連寫
                    # 會-記 得  1-1 2 錯誤
                    if len(環綴結尾詞) == 1:
                        錯誤行數 = 累積字長度 + 1
                        錯誤連字符位置 = '前'
                        錯誤訊息陣列.append(('E動詞（一）', 錯誤行數, 錯誤連字符位置))
                # 清除暫存的環綴起始詞
                # 會-記-得  1-1-1 合法～
                環綴起始詞 = None

        累積字長度 += 詞長度

    return 錯誤訊息陣列


def 是否符合咧原則(句物件):
    錯誤訊息陣列 = []
    累積字長度 = 0
    詞物件陣列 = 句物件.網出詞物件()
    總詞數 = len(詞物件陣列)
    前一个詞分詞 = None
    for 詞位置, 詞物件 in enumerate(詞物件陣列):
        詞的字物件陣列 = 詞物件.篩出字物件()
        詞長度 = len(詞的字物件陣列)
        詞分詞 = 詞物件.轉音(臺灣閩南語羅馬字拼音).看分詞()
        是最後一個詞 = (詞位置 + 1 == 總詞數)
        for 字位置, 字物件 in enumerate(詞的字物件陣列):
            字分詞 = 字物件.轉音(臺灣閩南語羅馬字拼音).看分詞()

            是咧 = (字分詞 in ('咧｜leh4', '咧｜teh4'))
            前半段的詞 = 詞(詞的字物件陣列[:字位置]).轉音(臺灣閩南語羅馬字拼音).看分詞()

            if 是咧:
                # 咧應和前面動詞連寫 徛咧講 => 徛-咧講
                # if 這個詞只有咧 and 前一個詞是動詞:
                if 詞長度 == 1 and 前一个詞分詞 and 是動詞(前一个詞分詞):
                    錯誤行數 = 累積字長度 + 字位置 + 1
                    錯誤連字符位置 = '前'
                    錯誤訊息陣列.append(('E動詞（二）', 錯誤行數, 錯誤連字符位置))

                # 咧應和前面非動詞分寫 我-咧講 => 我咧講
                #  elif 這個詞的前半段不是動詞:
                elif not 是咧結尾詞組(詞分詞) and 前半段的詞 and not 是動詞(前半段的詞):
                    錯誤行數 = 累積字長度 + 字位置 + 1
                    錯誤連字符位置 = '前'
                    錯誤訊息陣列.append(('E動詞（二）', 錯誤行數, 錯誤連字符位置))

                # 咧在句尾時和前面動詞分寫 徛-咧 => 徛咧/徛--咧
                # elif 是最後一個詞 and 前半段的詞是動詞 and 咧是最後一個字:
                elif (是最後一個詞 and 是動詞(前半段的詞) and 字位置 + 1 == 詞長度):
                    錯誤行數 = 累積字長度 + 字位置 + 1
                    錯誤連字符位置 = '前'
                    錯誤訊息陣列.append(('E動詞（二）', 錯誤行數, 錯誤連字符位置))

                # 咧應和後面分寫 咧-講 => 咧講
                # if 不是咧開頭詞組 and 這個詞的後半段還有字:
                if not 是咧開頭詞組(詞分詞) and (詞長度 - 字位置 - 1 > 0):
                    錯誤行數 = 累積字長度 + 字位置 + 1
                    錯誤連字符位置 = '後'
                    錯誤訊息陣列.append(('E動詞（二）', 錯誤行數, 錯誤連字符位置))

        累積字長度 += 詞長度
        前一个詞分詞 = 詞分詞
    return 錯誤訊息陣列


def 是否符合著原則(句物件):
    錯誤訊息陣列 = []
    累積字長度 = 0
    詞物件陣列 = 句物件.網出詞物件()
    前一个詞分詞 = None
    for 詞物件 in 詞物件陣列:
        詞的字物件陣列 = 詞物件.篩出字物件()
        詞長度 = len(詞的字物件陣列)
        詞分詞 = 詞物件.轉音(臺灣閩南語羅馬字拼音).看分詞()
        for 字位置, 字物件 in enumerate(詞的字物件陣列):
            字分詞 = 字物件.轉音(臺灣閩南語羅馬字拼音).看分詞()
            是著 = (字分詞 in ('著｜tioh8'))
            是過 = (字分詞 in ('過｜kue3', '過｜ke3'))

            if 是著 or 是過:
                # 著應和前面動詞連寫 我看著你 => 我看-著你
                if 詞長度 == 1 and 前一个詞分詞 and 是動詞(前一个詞分詞):
                    錯誤行數 = 累積字長度 + 字位置 + 1
                    錯誤連字符位置 = '前'
                    錯誤訊息陣列.append(('E動詞（二）', 錯誤行數, 錯誤連字符位置))

                # 著應和前面非動詞分寫，除非是詞組
                # 著在句尾時和前面動詞分寫 徛-咧 => 徛咧/徛--咧
                # 著時貌和後面分寫，跳過不處理 我看著-你 => 我看著你
                # 著時貌在句尾是輕聲調，跳過不處理 我有看著=>我有看--著
                # 著是動詞的開頭，跳過不處理 我著-病

        前一个詞分詞 = 詞分詞
        累積字長度 += 詞長度
    return 錯誤訊息陣列


def 符合單音節補語原則(句物件):
    錯誤訊息陣列 = []
    累積字長度 = 0
    詞物件陣列 = 句物件.網出詞物件()
    前一个詞分詞 = None
    前一个詞長度 = None
    for 詞物件 in 詞物件陣列:
        詞分詞 = 詞物件.轉音(臺灣閩南語羅馬字拼音).看分詞()
        字物件陣列 = 詞物件.篩出字物件()
        詞長度 = len(字物件陣列)
        # 單音節動詞+單音節補語 連寫
        if 前一个詞分詞 and 是動詞(前一个詞分詞) and 前一个詞長度 == 1 and 是補語(詞分詞) and 詞長度 == 1:
            錯誤行數 = 累積字長度 + 1
            錯誤連字符位置 = '前'
            錯誤訊息陣列.append(('E動詞（三）', 錯誤行數, 錯誤連字符位置))

        # 多音節動詞+單音節補語、單音節動詞+多音節補語 分寫
        if 詞長度 > 2:
            結尾兩字分詞 = 詞(字物件陣列[-2:]).轉音(臺灣閩南語羅馬字拼音).看分詞()
            兩字前半段分詞 = 詞(字物件陣列[:-2]).轉音(臺灣閩南語羅馬字拼音).看分詞()
            結尾一字分詞 = 詞(字物件陣列[-1:]).轉音(臺灣閩南語羅馬字拼音).看分詞()
            一字前半段分詞 = 詞(字物件陣列[:-1]).轉音(臺灣閩南語羅馬字拼音).看分詞()
            if 是補語(結尾兩字分詞) and 是動詞(兩字前半段分詞):
                #    排-好-勢
                # 行數 1  2  3
                #錯誤行數 = (累積字長處) + (詞長度-2) + 1
                錯誤行數 = 累積字長度 + 詞長度 - 1
                錯誤連字符位置 = '前'
                錯誤訊息陣列.append(('E動詞（三）', 錯誤行數, 錯誤連字符位置))
            elif 是補語(結尾一字分詞) and 是動詞(一字前半段分詞):
                #    整-理-好
                # 行數 1  2  3
                #錯誤行數 = (累積字長處) + (詞長度-1) + 1
                錯誤行數 = 累積字長度 + 詞長度
                錯誤連字符位置 = '前'
                錯誤訊息陣列.append(('E動詞（三）', 錯誤行數, 錯誤連字符位置))

        前一个詞長度 = 詞長度
        前一个詞分詞 = 詞分詞
        累積字長度 += 詞長度
    return 錯誤訊息陣列

==> lian5-ji7-hu5_kiam2-tsa1-0.4.1.tar.gz: lian5-ji7-hu5_kiam2-tsa1-0.4.1/連字符檢查/動詞原則/動詞.py <==
from 臺灣言語工具.音標系統.閩南語.臺灣閩南語羅馬字拼音 import 臺灣閩南語羅馬字拼音
from 臺灣言語工具.基本物件.詞 import 詞


def 是環綴起始(字分詞):
    集合 = ('會｜e7', '袂｜be7', '袂｜bue7')
    return 字分詞 in 集合


def 是環綴結尾(字分詞):
    集合 = ('得｜tit4', '得｜tsit4', '得｜lit4', '得｜eh4')
    return 字分詞 in 集合


def 是動詞(詞分詞):
    集合 = ('徛｜khia7','聽｜thiann1', '看｜khuann3', '講｜kong2', '排｜pai5', 
          '食｜tsiah8', '整-理｜tsing2-li2')
    return 詞分詞 in 集合


def 是助詞(字分詞):
    集合 = ('咧｜leh4', '咧｜teh4', '著｜tioh8', '過｜kue3')
    return 字分詞 in 集合


def 是咧結尾詞組(詞分詞):
    集合 = ('佇-咧｜ti7-leh4', '當-咧｜tng1-leh4', '當-咧｜tng1-teh4')
    return 詞分詞 in 集合


def 是咧開頭詞組(詞分詞):
    集合 = ('咧-欲｜teh4-beh4', )
    return 詞分詞 in 集合


def 是著結尾詞組(詞分詞):
    集合 = ('毋-著｜m̄-tio̍h',)
    return 詞分詞 in 集合


def 是補語(詞分詞):
    # 照字數排
    集合 = ('做-伙｜tso3-hue2', '好-勢｜ho2-se3', '煞｜suah4', '了｜liau2', '好｜ho2', )
    return 詞分詞 in 集合


def 是否符合環綴原則(句物件):
    # 動詞原則一：動詞與環綴連寫
    # 會...得，袂...得
    錯誤訊息陣列 = []
    累積字長度 = 0
    #
    # 我會記得你 -> 我, 會記得, 你
    詞物件陣列 = 句物件.網出詞物件()
    #
    # 會-記-得  1-1-1
    # 會-記 得  1-1 2 後面沒連寫
    # 會 記-得  1 2-2 錯誤
    # 會 記 得  1 2 3 錯誤
    #
    環綴起始詞 = None
    for 詞位置, 詞物件 in enumerate(詞物件陣列):
        詞的字物件陣列 = 詞物件.篩出字物件()
        詞長度 = len(詞的字物件陣列)

        for 字物件 in 詞的字物件陣列:
            字分詞 = 字物件.轉音(臺灣閩南語羅馬字拼音).看分詞()
            # 遇到可能是環綴起始的詞，先暫存此位置
            if 是環綴起始(字分詞):
                環綴起始詞 = {'詞位置': 詞位置, '字陣列': 詞的字物件陣列, '累積字長度': 累積字長度}
            # 遇到可能是環綴結尾的詞
            # if 是環綴結尾 and 前面有找到環綴起始詞 and 環綴起始詞的詞位置 != 現在環綴結尾詞的詞位置
            elif 是環綴結尾(字分詞) and 環綴起始詞:
                if 環綴起始詞['詞位置'] != 詞位置:
                    # 偵測到句子有出現環綴，檢查環綴的書寫是否正確
                    環綴結尾詞 = 詞的字物件陣列
                    # 首字應連寫
                    # 會 記-得  1 2-2 錯誤
                    # 會 記 得  1 2 3 錯誤
                    if len(環綴起始詞['字陣列']) == 1:
                        錯誤行數 = 環綴起始詞['累積字長度'] + 1
                        錯誤連字符位置 = '後'
                        錯誤訊息陣列.append(('E動詞（一）', 錯誤行數, 錯誤連字符位置))
                    # 尾字應連寫
                    # 會-記 得  1-1 2 錯誤
                    if len(環綴結尾詞) == 1:
                        錯誤行數 = 累積字長度 + 1
                        錯誤連字符位置 = '前'
                        錯誤訊息陣列.append(('E動詞（一）', 錯誤行數, 錯誤連字符位置))
                # 清除暫存的環綴起始詞
                # 會-記-得  1-1-1 合法～
                環綴起始詞 = None

        累積字長度 += 詞長度

    return 錯誤訊息陣列


def 是否符合咧原則(句物件):
    錯誤訊息陣列 = []
    累積字長度 = 0
    詞物件陣列 = 句物件.網出詞物件()
    總詞數 = len(詞物件陣列)
    前一个詞分詞 = None
    for 詞位置, 詞物件 in enumerate(詞物件陣列):
        詞的字物件陣列 = 詞物件.篩出字物件()
        詞長度 = len(詞的字物件陣列)
        詞分詞 = 詞物件.轉音(臺灣閩南語羅馬字拼音).看分詞()
        是最後一個詞 = (詞位置 + 1 == 總詞數)
        for 字位置, 字物件 in enumerate(詞的字物件陣列):
            字分詞 = 字物件.轉音(臺灣閩南語羅馬字拼音).看分詞()

            是咧 = (字分詞 in ('咧｜leh4', '咧｜teh4'))
            前半段的詞 = 詞(詞的字物件陣列[:字位置]).轉音(臺灣閩南語羅馬字拼音).看分詞()

            if 是咧:
                # 咧應和前面動詞連寫 徛咧講 => 徛-咧講
                # if 這個詞只有咧 and 前一個詞是動詞:
                if 詞長度 == 1 and 前一个詞分詞 and 是動詞(前一个詞分詞):
                    錯誤行數 = 累積字長度 + 字位置 + 1
                    錯誤連字符位置 = '前'
                    錯誤訊息陣列.append(('E動詞（二）', 錯誤行數, 錯誤連字符位置))

                # 咧應和前面非動詞分寫 我-咧講 => 我咧講
                #  elif 這個詞的前半段不是動詞:
                elif not 是咧結尾詞組(詞分詞) and 前半段的詞 and not 是動詞(前半段的詞):
                    錯誤行數 = 累積字長度 + 字位置 + 1
                    錯誤連字符位置 = '前'
                    錯誤訊息陣列.append(('E動詞（二）', 錯誤行數, 錯誤連字符位置))

                # 咧在句尾時和前面動詞分寫 徛-咧 => 徛咧/徛--咧
                # elif 是最後一個詞 and 前半段的詞是動詞 and 咧是最後一個字:
                elif (是最後一個詞 and 是動詞(前半段的詞) and 字位置 + 1 == 詞長度):
                    錯誤行數 = 累積字長度 + 字位置 + 1
                    錯誤連字符位置 = '前'
                    錯誤訊息陣列.append(('E動詞（二）', 錯誤行數, 錯誤連字符位置))

                # 咧應和後面分寫 咧-講 => 咧講
                # if 不是咧開頭詞組 and 這個詞的後半段還有字:
                if not 是咧開頭詞組(詞分詞) and (詞長度 - 字位置 - 1 > 0):
                    錯誤行數 = 累積字長度 + 字位置 + 1
                    錯誤連字符位置 = '後'
                    錯誤訊息陣列.append(('E動詞（二）', 錯誤行數, 錯誤連字符位置))

        累積字長度 += 詞長度
        前一个詞分詞 = 詞分詞
    return 錯誤訊息陣列


def 是否符合著原則(句物件):
    錯誤訊息陣列 = []
    累積字長度 = 0
    詞物件陣列 = 句物件.網出詞物件()
    前一个詞分詞 = None
    for 詞物件 in 詞物件陣列:
        詞的字物件陣列 = 詞物件.篩出字物件()
        詞長度 = len(詞的字物件陣列)
        詞分詞 = 詞物件.轉音(臺灣閩南語羅馬字拼音).看分詞()
        for 字位置, 字物件 in enumerate(詞的字物件陣列):
            字分詞 = 字物件.轉音(臺灣閩南語羅馬字拼音).看分詞()
            是著 = (字分詞 in ('著｜tioh8'))
            是過 = (字分詞 in ('過｜kue3', '過｜ke3'))

            if 是著 or 是過:
                # 著應和前面動詞連寫 我看著你 => 我看-著你
                if 詞長度 == 1 and 前一个詞分詞 and 是動詞(前一个詞分詞):
                    錯誤行數 = 累積字長度 + 字位置 + 1
                    錯誤連字符位置 = '前'
                    錯誤訊息陣列.append(('E動詞（二）', 錯誤行數, 錯誤連字符位置))

                # 著應和前面非動詞分寫，除非是詞組
                # 著在句尾時和前面動詞分寫 徛-咧 => 徛咧/徛--咧
                # 著時貌和後面分寫，跳過不處理 我看著-你 => 我看著你
                # 著時貌在句尾是輕聲調，跳過不處理 我有看著=>我有看--著
                # 著是動詞的開頭，跳過不處理 我著-病

        前一个詞分詞 = 詞分詞
        累積字長度 += 詞長度
    return 錯誤訊息陣列


def 符合單音節補語原則(句物件):
    錯誤訊息陣列 = []
    累積字長度 = 0
    詞物件陣列 = 句物件.網出詞物件()
    前一个詞分詞 = None
    前一个詞長度 = None
    for 詞物件 in 詞物件陣列:
        詞分詞 = 詞物件.轉音(臺灣閩南語羅馬字拼音).看分詞()
        字物件陣列 = 詞物件.篩出字物件()
        詞長度 = len(字物件陣列)
        # 單音節動詞+單音節補語 連寫
        if 前一个詞分詞 and 是動詞(前一个詞分詞) and 前一个詞長度 == 1 and 是補語(詞分詞) and 詞長度 == 1:
            錯誤行數 = 累積字長度 + 1
            錯誤連字符位置 = '前'
            錯誤訊息陣列.append(('E動詞（三）', 錯誤行數, 錯誤連字符位置))

        # 多音節動詞+單音節補語、單音節動詞+多音節補語 分寫
        if 詞長度 > 2:
            結尾兩字分詞 = 詞(字物件陣列[-2:]).轉音(臺灣閩南語羅馬字拼音).看分詞()
            兩字前半段分詞 = 詞(字物件陣列[:-2]).轉音(臺灣閩南語羅馬字拼音).看分詞()
            結尾一字分詞 = 詞(字物件陣列[-1:]).轉音(臺灣閩南語羅馬字拼音).看分詞()
            一字前半段分詞 = 詞(字物件陣列[:-1]).轉音(臺灣閩南語羅馬字拼音).看分詞()
            if 是補語(結尾兩字分詞) and 是動詞(兩字前半段分詞):
                #    排-好-勢
                # 行數 1  2  3
                #錯誤行數 = (累積字長處) + (詞長度-2) + 1
                錯誤行數 = 累積字長度 + 詞長度 - 1
                錯誤連字符位置 = '前'
                錯誤訊息陣列.append(('E動詞（三）', 錯誤行數, 錯誤連字符位置))
            elif 是補語(結尾一字分詞) and 是動詞(一字前半段分詞):
                #    整-理-好
                # 行數 1  2  3
                #錯誤行數 = (累積字長處) + (詞長度-1) + 1
                錯誤行數 = 累積字長度 + 詞長度
                錯誤連字符位置 = '前'
                錯誤訊息陣列.append(('E動詞（三）', 錯誤行數, 錯誤連字符位置))

        前一个詞長度 = 詞長度
        前一个詞分詞 = 詞分詞
        累積字長度 += 詞長度
    return 錯誤訊息陣列
